from .base import BaseCFObject


class Rule(BaseCFObject):
    top_level_key = "Rules"
